@@ -23,6 +23,7 @@
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Intevation GmbH <intevation@intevation.de>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -35,7 +36,6 @@
 #include <string.h>
 #include "goo/gmem.h"
 #include "goo/GooString.h"
-#include "goo/GooList.h"
 #include "Error.h"
 #include "Object.h"
 #include "Array.h"
@@ -53,8 +53,12 @@ LinkAction::LinkAction() : nextActionList(nullptr) {
 }
 
 LinkAction::~LinkAction() {
-  if (nextActionList)
-    deleteGooList<LinkAction>(nextActionList);
+  if (nextActionList) {
+    for (auto entry : *nextActionList) {
+      delete entry;
+    }
+    delete nextActionList;
+  }
 }
 
 LinkAction *LinkAction::parseDest(const Object *obj) {
@@ -158,7 +162,7 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
 
   // parse the next actions
   const Object nextObj = obj->dictLookup("Next");
-  GooList *actionList = nullptr;
+  std::vector<LinkAction*> *actionList = nullptr;
   if (nextObj.isDict()) {
 
     // Prevent circles in the tree by checking the ref against used refs in
@@ -172,13 +176,13 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
         }
     }
 
-    actionList = new GooList();
+    actionList = new std::vector<LinkAction*>();
     actionList->reserve(1);
     actionList->push_back(parseAction(&nextObj, nullptr, seenNextActions));
   } else if (nextObj.isArray()) {
     const Array *a = nextObj.getArray();
     const int n = a->getLength();
-    actionList = new GooList();
+    actionList = new std::vector<LinkAction*>();
     actionList->reserve(n);
     for (int i = 0; i < n; ++i) {
       const Object obj3 = a->get(i);
@@ -206,11 +210,11 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
   return action;
 }
 
-const GooList *LinkAction::nextActions() const {
+const std::vector<LinkAction*> *LinkAction::nextActions() const {
   return nextActionList;
 }
 
-void LinkAction::setNextActions(GooList *actions) {
+void LinkAction::setNextActions(std::vector<LinkAction*> *actions) {
   delete nextActionList;
   nextActionList = actions;
 }
@@ -235,8 +239,7 @@ LinkDest::LinkDest(const Array *a) {
     pageNum = obj0.getInt() + 1;
     pageIsRef = false;
   } else if (obj0.isRef()) {
-    pageRef.num = obj0.getRefNum();
-    pageRef.gen = obj0.getRefGen();
+    pageRef = obj0.getRef();
     pageIsRef = true;
   } else {
     error(errSyntaxWarning, -1, "Bad annotation destination");
@@ -634,7 +637,7 @@ LinkNamed::~LinkNamed() {
 //------------------------------------------------------------------------
 
 LinkMovie::LinkMovie(const Object *obj) {
-  annotRef.num = -1;
+  annotRef = Ref::INVALID();
   annotTitle = nullptr;
 
   const Object &annotationObj = obj->dictLookupNF("Annotation");
@@ -647,7 +650,7 @@ LinkMovie::LinkMovie(const Object *obj) {
     annotTitle = tmp.getString()->copy();
   }
 
-  if ((annotTitle == nullptr) && (annotRef.num == -1)) {
+  if ((annotTitle == nullptr) && (annotRef == Ref::INVALID())) {
     error(errSyntaxError, -1,
 	  "Movie action is missing both the Annot and T keys");
   }
@@ -729,7 +732,7 @@ LinkRendition::LinkRendition(const Object *obj) {
   js = nullptr;
   int operationCode = -1;
 
-  screenRef.num = -1;
+  screenRef = Ref::INVALID();
 
   if (obj->isDict()) {
     Object tmp = obj->dictLookup("JS");
@@ -824,7 +827,7 @@ LinkJavaScript::~LinkJavaScript() {
 // LinkOCGState
 //------------------------------------------------------------------------
 LinkOCGState::LinkOCGState(const Object *obj) {
-  stateList = new GooList();
+  stateList = new std::vector<StateList*>();
   preserveRB = true;
 
   Object obj1 = obj->dictLookup("State");
@@ -839,7 +842,7 @@ LinkOCGState::LinkOCGState(const Object *obj) {
 
 	const char *name = obj2.getName();
 	stList = new StateList();
-	stList->list = new GooList();
+	stList->list = new std::vector<Ref*>();
 	if (!strcmp (name, "ON")) {
 	  stList->st = On;
 	} else if (!strcmp (name, "OFF")) {
@@ -855,8 +858,7 @@ LinkOCGState::LinkOCGState(const Object *obj) {
         if (stList) {
 	  Ref ocgRef = obj2.getRef();
 	  Ref *item = new Ref();
-	  item->num = ocgRef.num;
-	  item->gen = ocgRef.gen;
+	  *item = ocgRef;
 	  stList->list->push_back(item);
 	} else {
 	  error(errSyntaxWarning, -1, "Invalid OCG Action State array, expected name instead of ref");
@@ -881,13 +883,21 @@ LinkOCGState::LinkOCGState(const Object *obj) {
 }
 
 LinkOCGState::~LinkOCGState() {
-  if (stateList)
-    deleteGooList<StateList>(stateList);
+  if (stateList) {
+    for (auto entry : *stateList) {
+      delete entry;
+    }
+    delete stateList;
+  }
 }
 
 LinkOCGState::StateList::~StateList() {
-  if (list)
-    deleteGooList<Ref>(list);
+  if (list) {
+    for (auto entry : *list) {
+      delete entry;
+    }
+    delete list;
+  }
 }
 
 //------------------------------------------------------------------------
